==> media-type-version-0.2.0.tar.bz2: media-type-version-0.2.0/docs/download.md <==
<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [media-type-version](index.md) available for download.

## [0.2.0] - 2025-10-09

### Source tarball

- [media-type-version-0.2.0.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.gz.asc))
- [media-type-version-0.2.0.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.bz2.asc))
- [media-type-version-0.2.0.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.xz.asc))

## [0.1.3] - 2025-06-16

### Source tarball

- [media-type-version-0.1.3.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.gz.asc))
- [media-type-version-0.1.3.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.bz2.asc))
- [media-type-version-0.1.3.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.xz.asc))

## [0.1.2] - 2025-06-08

### Source tarball

- [media-type-version-0.1.2.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.gz.asc))
- [media-type-version-0.1.2.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.bz2.asc))
- [media-type-version-0.1.2.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.xz.asc))

## [0.1.1] - 2025-05-23

### Source tarball

- [media-type-version-0.1.1.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.gz.asc))
- [media-type-version-0.1.1.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.bz2.asc))
- [media-type-version-0.1.1.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.xz.asc))

## [0.1.0] - 2025-05-23

### Source tarball

- [media-type-version-0.1.0.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.gz.asc))
- [media-type-version-0.1.0.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.bz2.asc))
- [media-type-version-0.1.0.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.xz.asc))

[0.2.0]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.2.0
[0.1.3]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.3
[0.1.2]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.2
[0.1.1]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.1
[0.1.0]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.0

==> media-type-version-0.2.1.tar.bz2: media-type-version-0.2.1/docs/download.md <==
<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [media-type-version](index.md) available for download.

## [0.2.1] - 2025-12-20

### Source tarball

- [media-type-version-0.2.1.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.1.tar.gz.asc))
- [media-type-version-0.2.1.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.1.tar.bz2.asc))
- [media-type-version-0.2.1.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.1.tar.xz.asc))

## [0.2.0] - 2025-10-09

### Source tarball

- [media-type-version-0.2.0.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.gz.asc))
- [media-type-version-0.2.0.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.bz2.asc))
- [media-type-version-0.2.0.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.2.0.tar.xz.asc))

## [0.1.3] - 2025-06-16

### Source tarball

- [media-type-version-0.1.3.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.gz.asc))
- [media-type-version-0.1.3.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.bz2.asc))
- [media-type-version-0.1.3.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.3.tar.xz.asc))

## [0.1.2] - 2025-06-08

### Source tarball

- [media-type-version-0.1.2.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.gz.asc))
- [media-type-version-0.1.2.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.bz2.asc))
- [media-type-version-0.1.2.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.2.tar.xz.asc))

## [0.1.1] - 2025-05-23

### Source tarball

- [media-type-version-0.1.1.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.gz.asc))
- [media-type-version-0.1.1.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.bz2.asc))
- [media-type-version-0.1.1.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.1.tar.xz.asc))

## [0.1.0] - 2025-05-23

### Source tarball

- [media-type-version-0.1.0.tar.gz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.gz.asc))
- [media-type-version-0.1.0.tar.bz2](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.bz2)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.bz2.asc))
- [media-type-version-0.1.0.tar.xz](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.xz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/media-type-version/media-type-version-0.1.0.tar.xz.asc))

[0.2.1]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.2.1
[0.2.0]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.2.0
[0.1.3]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.3
[0.1.2]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.2
[0.1.1]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.1
[0.1.0]: https://gitlab.com/ppentchev/media-type-version/-/tags/release%2F0.1.0
